Struct skipfree::SkipList

source ·
pub struct SkipList<K, V> { /* private fields */ }
A lock-free skip list, generic over keys and values.

Implementations

source

impl<K: Eq + Ord + Default, V: Default> SkipList<K, V>

source

pub fn insert(&self, key: K, value: V)

Insert the provided key and value into the skiplist.

source

pub fn contains(&self, key: &K) -> bool

True iff the skiplist contains key.

source

pub fn iter(&self) -> SkipListIterator<K, V>

Return a skiplist iterator.

This iterator will keep the body of the skiplist in-memory even after the skiplist itself goes out of scope.